tarball — Transifex v0.8.0 documentation

# Transifex v0.8.0 documentation

# `tarball`

## Models

This module contains a model that is expected to be used for the codebases used by Transifex. The following definitions are used:

resource:
  A file within a codebase
codebase:
  A collection of files (VCS repo, tarball, etc.) that contains resources, some or all of which are to be translated

class `Tarball`(*args, **kwargs)
  A tarball found on a remote server. It is controlled locally via a mercurial repo.

## Library

### tarball backends

class `TarballBrowser`(root, name=None)

  A browser class for tarballs

  `init_codebase`()
    Set the codebase attribute if the codebase has been setup Otherwise, set it up
  `remote_path`
    Return remote path for cloning.
  `setup_codebase`()
    Download and extract tarball